package com.ruoyi.manage.service.impl;

import java.util.List;




















import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.manage.mapper.RecordInspectionInfoMapper;
import com.ruoyi.manage.domain.RecordInspectionInfo;
import com.ruoyi.manage.service.IRecordInspectionInfoService;
import com.ruoyi.common.core.text.Convert;

/**
 * 盘点数据记录Service业务层处理
 *
 * @author wangh
 * @date 2024-02-18
 */
@Service
public class RecordInspectionInfoServiceImpl implements IRecordInspectionInfoService {
    @Autowired
    private RecordInspectionInfoMapper recordInspectionInfoMapper;

    /**
     * 查询盘点数据记录
     *
     * @param inspectionId 盘点数据记录主键
     * @return 盘点数据记录
     */
    @Override
    public RecordInspectionInfo selectRecordInspectionInfoByInspectionId(Long inspectionId) {
        return recordInspectionInfoMapper.selectRecordInspectionInfoByInspectionId(inspectionId);
    }

    /**
     * 查询盘点数据记录列表
     *
     * @param recordInspectionInfo 盘点数据记录
     * @return 盘点数据记录
     */
    @Override
    public List<RecordInspectionInfo> selectRecordInspectionInfoList(RecordInspectionInfo recordInspectionInfo) {
        return recordInspectionInfoMapper.selectRecordInspectionInfoList(recordInspectionInfo);
    }

    /**
     * 新增盘点数据记录
     *
     * @param recordInspectionInfo 盘点数据记录
     * @return 结果
     */
    @Override
    public int insertRecordInspectionInfo(RecordInspectionInfo recordInspectionInfo) {





            return recordInspectionInfoMapper.insertRecordInspectionInfo(recordInspectionInfo);
    }

    /**
     * 修改盘点数据记录
     *
     * @param recordInspectionInfo 盘点数据记录
     * @return 结果
     */
    @Override
    public int updateRecordInspectionInfo(RecordInspectionInfo recordInspectionInfo) {
        return recordInspectionInfoMapper.updateRecordInspectionInfo(recordInspectionInfo);
    }

    /**
     * 批量删除盘点数据记录
     *
     * @param inspectionIds 需要删除的盘点数据记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordInspectionInfoByInspectionIds(String inspectionIds) {
        return recordInspectionInfoMapper.deleteRecordInspectionInfoByInspectionIds(Convert.toStrArray(inspectionIds));
    }

    /**
     * 删除盘点数据记录信息
     *
     * @param inspectionId 盘点数据记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordInspectionInfoByInspectionId(Long inspectionId) {
        return recordInspectionInfoMapper.deleteRecordInspectionInfoByInspectionId(inspectionId);
    }
}
